@@ -1,7 +1,7 @@
 '''HyperEstraier
 Hiroki Ohtani
 "HyperEstraier Pure Python Implementation."
-http://www.liris.org/trac/wiki/PyHyperEstraier
+http://coderepos.org/share/wiki/PyHyperEstraier
 '''
 
 
@@ -12,9 +12,8 @@ import urllib
 import urllib2
 import re
 
-__version__  = '0.10.6'
-__author__ = "Hiroki Ohtani (liris.pp@gmail.com)"
-__contributors__ = ["Junji NAKANISHI <daemonfreaks@gmail.com>"]
+__version__  = '0.10.7'
+__author__ = "Hiroki Ohtani (liris.pp [at] gmail.com)"
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
 __license__ = "LGPL"
 
@@ -853,63 +852,53 @@ class Node(object):
             hints = {}
             nres = NodeResult(docs, hints)
             border = lines.pop(0)
-            isend = False
-            while len(lines):
-                line = lines.pop(0)
-                if line.startswith(border):
-                    if line[len(border)+1:] == ":END":
-                        isend = True
-                    lines.insert(0, line)
-                    break
+            sections = result.split(border)
+            if len(sections) < 3:
+                return None
+            sections = sections[1:-1]
+            ehits = 0
+            for line in sections[0].splitlines():
                 elems = line.split("\t", 1)
                 if len(elems) == 2:
                     hints[elems[0]] = elems[1]
+                    if 'HIT' == elems[0]:
+                        ehits = int(elems[1])
 
-            while not isend and len(lines):
-                line = lines.pop(0)
-                if line.startswith(border):
-                    rdattrs = {}
-                    sb = []
-                    rdvector = ""
-                    while len(lines):
-                        rdline = lines.pop(0).strip()
-                        if not rdline:
-                            break
-                        if rdline.startswith("%"):
-                            vecelem = rdline.split("\t", 1)
-                            if len(vecelem) == 2 and vecelem[0] == "%VECTOR":
-                                rdvector = vecelem[1]
-                        else:
-                            elems = rdline.split("=", 1)
-                            if len(elems)==2:
-                                rdattrs[elems[0]] = elems[1]
+            for section in sections[1:]:
+                lines = [line.strip() for line in section.splitlines()]
+                if len(lines) < 4:
+                    return None
+                if lines[0] == '':
+                    del lines[0]
+                if lines[-1] == '':
+                    del lines[-1]
+                section = '\n'.join(lines)
+                _split = section.split('\n\n')
+                if len(_split) != 2:
+                    return None
+                rdlines = _split[0].splitlines()
+                sb = _split[1].splitlines()
+                rdattrs = {}
+                rdvector = ""
+                for rdline in rdlines:
+                    if rdline.startswith("%"):
+                        vecelem = rdline.split("\t", 1)
+                        if len(vecelem) == 2 and vecelem[0] == "%VECTOR":
+                            rdvector = vecelem[1]
+                    else:
+                        elems = rdline.split("=", 1)
+                        if len(elems)==2:
+                            rdattrs[elems[0]] = elems[1]
 
-                    inSnippet = False
-                    snippetEnd = border + ":END"
-                    while len(lines):
-                        rdline = lines.pop(0)
-                        if not rdline:
-                        #    break
-                            if not inSnippet:
-                                inSnippet = True
-                            else:
-                                break
-                        if rdline == snippetEnd:
-                            isend = True
-                            break
-                        sb.append(rdline)
-                    rduri = rdattrs.setdefault("@uri", None)
-                    rdsnippet = "\n".join(sb)
-                    if rduri:
-                        rdoc = ResultDocument(rduri, rdattrs, rdsnippet, rdvector)
-                        docs.append(rdoc)
-                if line.endswith(":END"):
-                    isend = True
-                    break
+                rduri = rdattrs.setdefault("@uri", None)
+                rdsnippet = "\n".join(sb)
+                if rduri:
+                    rdoc = ResultDocument(rduri, rdattrs, rdsnippet, rdvector)
+                    docs.append(rdoc)
 
-            if isend:
-                return nres
-            return None
+            if len(docs) != ehits:
+                return None
+            return nres
 
         def err(resutl):
             return None
